@@ -6,17 +6,16 @@ use HTTP::Engine;
 use HTTP::Engine::Interface::POE;
 use HTTP::Response;
 use HTTP::Engine::Request;
-use HTTP::MobileAttribute;
 use String::TT qw/strip tt/;
 
 my $engine = HTTP::Engine->new(
     interface => HTTP::Engine::Interface::POE->new({
         port    => 3999,
         request_handler => sub {
-            my $c = shift;
+            my $req = shift;
             local $Data::Dumper::Sortkeys = 1;
-            my $req_dump = Dumper( $c->req );
-            my $raw      = $c->req->raw_body;
+            my $req_dump = Dumper( $req );
+            my $raw      = $req->raw_body;
             my $body     = strip tt q{ 
                 <form method="post">
                     <input type="text" name="foo" />
@@ -32,7 +31,7 @@ my $engine = HTTP::Engine->new(
                 <pre>[% req_dump | html %]</pre>
             };
 
-            $c->res->body($body);
+            HTTP::Engine::Response->new( body => $body );
         },
     }),
 );
